EDHOC Values

CBOR shortcut constants and key-derivation labels used internally by libedhoc and exposed in include/edhoc_values.h. These are reference enums; for the EDHOC error codes see EDHOC Error Codes.

Header file: include/edhoc_values.h

CBOR one-byte values

group EDHOC CBOR one byte

Note

It must follow the RFC 9528: 3.3.2. Representation of Byte String Identifiers.

Defines

ONE_BYTE_CBOR_INT_MIN_VALUE

Minimum value for CBOR one byte integer.

ONE_BYTE_CBOR_INT_MAX_VALUE

Maximum value for CBOR one byte integer.

CBOR primitive values

group EDHOC CBOR primitive values

Standard CBOR primitive values that may be used in EDHOC implementations.

Defines

EDHOC_CBOR_TRUE

CBOR encoding for boolean true (RFC 8949: 3.3.1. Major Type 7).

Extract / expand labels

group EDHOC extract labels

Defines

EDHOC_EXTRACT_PRK_INFO_LABEL_KEYSTREAM_2

KEYSTREAM_2 from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_KEYSTERAM_2

Deprecated:

Use EDHOC_EXTRACT_PRK_INFO_LABEL_KEYSTREAM_2 instead.

EDHOC_EXTRACT_PRK_INFO_LABEL_SALT_3E2M

SALT_3e2m from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_MAC_2

MAC_2 from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_K_3

K_3 from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_IV_3

IV_3 from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_SALT_4E3M

SALT_4e3m from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_MAC_3

MAC_3 from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_PRK_OUT

PRK_out from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_K_4

K_4 from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_IV_4

IV_4 from RFC 9528: 4.1.2. EDHOC_Expand and EDHOC_KDF.

EDHOC_EXTRACT_PRK_INFO_LABEL_PRK_EXPORTER

PRK_Exporter from RFC 9528: 4.2.1. EDHOC_Exporter.

EDHOC_EXTRACT_PRK_INFO_LABEL_NEW_PRK_OUT

PRK_out from RFC 9528: 4.1.3. PRK_out.

OSCORE_EXTRACT_LABEL_MASTER_SECRET

RFC 9528: A.1. Deriving the OSCORE Security Context.

EDHOC exporter label for OSCORE Master Secret from RFC 9528: A.1. Deriving the OSCORE Security Context.

OSCORE_EXTRACT_LABEL_MASTER_SALT

EDHOC exporter label for OSCORE Master Salt from RFC 9528: A.1. Deriving the OSCORE Security Context.

EDHOC_PRK_EXPORTER_PRIVATE_LABEL_MINIMUM

RFC 9528: 10.1. EDHOC Exporter Label Registry.

Minimum value for EDHOC exporter label for private usage.

EDHOC_PRK_EXPORTER_PRIVATE_LABEL_MAXIMUM

Maximum value for EDHOC exporter label for private usage.